#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("This indicator calculates the ratio of a short period ATR to a long period ATR to help determine when the market is trending. Originally created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.")]
    [Gui.Design.DisplayName("ATR Ratio")]
	public class ATRratio : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int shortATR = 7; // Default setting for ShortATR
            private int longATR = 49; // Default setting for LongATR
            private double triggerLevel = 1; // Default setting for TriggerLevel
			private double temp1, temp2, temp3;
			private bool colorBackground = true;
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.DimGray), PlotStyle.Line, "Ratio"));
			Add(new Plot(Color.DarkGray, PlotStyle.Line, "Trigger"));
			Plots[1].Pen.DashStyle = DashStyle.Dash;
			Plots[0].Pen.Width = 2;
			Plots[1].Pen.Width = 2;
            CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {

			if (CurrentBar < longATR+1)
			{
				return;
			}
			
			temp1=ATR(shortATR)[0];
			temp2=ATR(longATR)[0];
			temp3 =temp1/temp2;
			
			
			if(colorBackground)
			{
				if (temp3 < triggerLevel)
				{
					BackColor = Color.MistyRose;
				}
				else
				{
					BackColor = Color.LightCyan;
				}
					
			}
					
				
			Trigger.Set(triggerLevel);
			Ratio.Set(temp3);
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Ratio
        {
            get { return Values[0]; }
        }
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Trigger
        {
            get { return Values[1]; }
        }
		
		[Description("Color the indicator background?")]
        [Category("Visual")]
		[Gui.Design.DisplayName ("Color Background?")]
        public bool ColorBackground
        {
            get { return colorBackground; }
            set { colorBackground = value; }
        }

        [Description("Period for short ATR")]
        [Category("Parameters")]
        public int ShortATR
        {
            get { return shortATR; }
            set { shortATR = Math.Max(1, value); }
        }

        [Description("Period for long ATR")]
        [Category("Parameters")]
        public int LongATR
        {
            get { return longATR; }
            set { longATR = Math.Max(1, value); }
        }

        [Description("Trigger Level (double)")]
        [Category("Parameters")]
        public double TriggerLevel
        {
            get { return triggerLevel; }
            set { triggerLevel = Math.Max(0.0001, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private ATRratio[] cacheATRratio = null;

        private static ATRratio checkATRratio = new ATRratio();

        /// <summary>
        /// This indicator calculates the ratio of a short period ATR to a long period ATR to help determine when the market is trending. Originally created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public ATRratio ATRratio(int longATR, int shortATR, double triggerLevel)
        {
            return ATRratio(Input, longATR, shortATR, triggerLevel);
        }

        /// <summary>
        /// This indicator calculates the ratio of a short period ATR to a long period ATR to help determine when the market is trending. Originally created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public ATRratio ATRratio(Data.IDataSeries input, int longATR, int shortATR, double triggerLevel)
        {
            checkATRratio.LongATR = longATR;
            longATR = checkATRratio.LongATR;
            checkATRratio.ShortATR = shortATR;
            shortATR = checkATRratio.ShortATR;
            checkATRratio.TriggerLevel = triggerLevel;
            triggerLevel = checkATRratio.TriggerLevel;

            if (cacheATRratio != null)
                for (int idx = 0; idx < cacheATRratio.Length; idx++)
                    if (cacheATRratio[idx].LongATR == longATR && cacheATRratio[idx].ShortATR == shortATR && Math.Abs(cacheATRratio[idx].TriggerLevel - triggerLevel) <= double.Epsilon && cacheATRratio[idx].EqualsInput(input))
                        return cacheATRratio[idx];

            ATRratio indicator = new ATRratio();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.LongATR = longATR;
            indicator.ShortATR = shortATR;
            indicator.TriggerLevel = triggerLevel;
            indicator.SetUp();

            ATRratio[] tmp = new ATRratio[cacheATRratio == null ? 1 : cacheATRratio.Length + 1];
            if (cacheATRratio != null)
                cacheATRratio.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheATRratio = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// This indicator calculates the ratio of a short period ATR to a long period ATR to help determine when the market is trending. Originally created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ATRratio ATRratio(int longATR, int shortATR, double triggerLevel)
        {
            return _indicator.ATRratio(Input, longATR, shortATR, triggerLevel);
        }

        /// <summary>
        /// This indicator calculates the ratio of a short period ATR to a long period ATR to help determine when the market is trending. Originally created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public Indicator.ATRratio ATRratio(Data.IDataSeries input, int longATR, int shortATR, double triggerLevel)
        {
            return _indicator.ATRratio(input, longATR, shortATR, triggerLevel);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// This indicator calculates the ratio of a short period ATR to a long period ATR to help determine when the market is trending. Originally created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ATRratio ATRratio(int longATR, int shortATR, double triggerLevel)
        {
            return _indicator.ATRratio(Input, longATR, shortATR, triggerLevel);
        }

        /// <summary>
        /// This indicator calculates the ratio of a short period ATR to a long period ATR to help determine when the market is trending. Originally created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public Indicator.ATRratio ATRratio(Data.IDataSeries input, int longATR, int shortATR, double triggerLevel)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.ATRratio(input, longATR, shortATR, triggerLevel);
        }

    }
}
#endregion
